@@ -178,6 +178,8 @@ void AltTransView::process()
     }
 
     CatalogString source = m_catalog->sourceWithTags(m_entry.toDocPosition());
+    QString context = m_catalog->context(m_entry.toDocPosition()).first();
+    QString contextWithNewline = context + (context.isEmpty() ? "" : "\n");
 
     QTextBlockFormat blockFormatBase;
     QTextBlockFormat blockFormatAlternate; blockFormatAlternate.setBackground(QPalette().alternateBase());
@@ -194,7 +196,7 @@ void AltTransView::process()
         if (!entry.source.isEmpty()) {
             html += QStringLiteral("<p>");
 
-            QString result = userVisibleWordDiff(entry.source.string, source.string, Project::instance()->accel(), Project::instance()->markup()).toHtmlEscaped();
+            QString result = userVisibleWordDiff(entry.source.string, contextWithNewline + source.string, Project::instance()->accel(), Project::instance()->markup()).toHtmlEscaped();
             //result.replace("&","&amp;");
             //result.replace("<","&lt;");
             //result.replace(">","&gt;");
@@ -202,7 +204,7 @@ void AltTransView::process()
             result.replace(QStringLiteral("{/KBABELADD}"), QStringLiteral("</font>"));
             result.replace(QStringLiteral("{KBABELDEL}"), QStringLiteral("<font style=\"background-color:") % Settings::delColor().name() % QStringLiteral(";color:black\">"));
             result.replace(QStringLiteral("{/KBABELDEL}"), QStringLiteral("</font>"));
-            result.replace(QStringLiteral("\\n"), QStringLiteral("\\n<br><br>"));
+            result.replace(QStringLiteral("\\n"), QStringLiteral("\\n<br>"));
 
             html += result;
             html += QStringLiteral("<br>");
